@@ -1,6 +1,6 @@
 /* t1fontskel.cc -- Type 1 font skeleton
  *
- * Copyright (c) 1998-2012 Eddie Kohler
+ * Copyright (c) 1998-2016 Eddie Kohler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -24,190 +24,89 @@
 #include <ctype.h>
 namespace Efont {
 
-static const char *othersubrs_code = "% Copyright (c) 1987-1990 Adobe Systems Incorporated.\n"
-"% All Rights Reserved.\n"
-"% This code to be used for Flex and hint replacement.\n"
-"% Version 1.1\n"
-"/OtherSubrs\n"
-"[systemdict /internaldict known\n"
-"{1183615869 systemdict /internaldict get exec\n"
-"/FlxProc known {save true} {false} ifelse}\n"
-"{userdict /internaldict known not {\n"
-"userdict /internaldict\n"
-"{count 0 eq\n"
-"{/internaldict errordict /invalidaccess get exec} if\n"
-"dup type /integertype ne\n"
-"{/internaldict errordict /invalidaccess get exec} if\n"
-"dup 1183615869 eq\n"
-"{pop 0}\n"
-"{/internaldict errordict /invalidaccess get exec}\n"
-"ifelse\n"
-"}\n"
-"dup 14 get 1 25 dict put\n"
-"bind executeonly put\n"
-"} if\n"
-"1183615869 userdict /internaldict get exec\n"
-"/FlxProc known {save true} {false} ifelse}\n"
-"ifelse\n"
+#if HAVE_ADOBE_CODE
+
+static const char* othersubrs_code =
+// This version of the OtherSubrs code for old PostScript interpreters comes from
+// https://github.com/adobe-type-tools/afdko/blob/master/FDK/Tools/Programs/public/lib/source/t1write/t1write_flexothers.txt
+// (commit 3f4eeec). The Adobe Font Development Kit is licensed by the Apache
+// License, 2.0, which permits this embedding.
+"% Copyright 1987-1990 Adobe Systems Incorporated. All rights reserved.\n"
+"/OtherSubrs[systemdict/internaldict known{1183615869 systemdict/internaldict\n"
+"get exec/FlxProc known{save true}{false}ifelse}{userdict/internaldict known\n"
+"not{userdict/internaldict{count 0 eq{/internaldict errordict/invalidaccess get\n"
+"exec}if dup type/integertype ne{/internaldict errordict/invalidaccess get exec\n"
+"}if dup 1183615869 eq{pop 0}{/internaldict errordict/invalidaccess get exec}\n"
+"ifelse}dup 14 get 1 25 dict put bind executeonly put}if 1183615869 userdict\n"
+"/internaldict get exec/FlxProc known{save true}{false}ifelse}ifelse[systemdict\n"
+"/internaldict known not{100 dict/begin cvx/mtx matrix/def cvx}if systemdict\n"
+"/currentpacking known{currentpacking true setpacking}if{systemdict\n"
+"/internaldict known{1183615869 systemdict/internaldict get exec dup/$FlxDict\n"
+"known not{dup dup length exch maxlength eq{pop userdict dup/$FlxDict known not\n"
+"{100 dict begin/mtx matrix def dup/$FlxDict currentdict put end}if}{100 dict\n"
+"begin/mtx matrix def dup/$FlxDict currentdict put end}ifelse}if/$FlxDict get\n"
+"begin}if grestore/exdef{exch def}def/dmin exch abs 100 div def/epX exdef/epY\n"
+"exdef/c4y2 exdef/c4x2 exdef/c4y1 exdef/c4x1 exdef/c4y0 exdef/c4x0 exdef/c3y2\n"
+"exdef/c3x2 exdef/c3y1 exdef/c3x1 exdef/c3y0 exdef/c3x0 exdef/c1y2 exdef/c1x2\n"
+"exdef/c2x2 c4x2 def/c2y2 c4y2 def/yflag c1y2 c3y2 sub abs c1x2 c3x2 sub abs gt\n"
+"def/PickCoords{{c1x0 c1y0 c1x1 c1y1 c1x2 c1y2 c2x0 c2y0 c2x1 c2y1 c2x2 c2y2}{\n"
+"c3x0 c3y0 c3x1 c3y1 c3x2 c3y2 c4x0 c4y0 c4x1 c4y1 c4x2 c4y2}ifelse/y5 exdef/x5\n"
+"exdef/y4 exdef/x4 exdef/y3 exdef/x3 exdef/y2 exdef/x2 exdef/y1 exdef/x1 exdef\n"
+"/y0 exdef/x0 exdef}def mtx currentmatrix pop mtx 0 get abs 1e-05 lt mtx 3 get\n"
+"abs 1e-05 lt or{/flipXY -1 def}{mtx 1 get abs 1e-05 lt mtx 2 get abs 1e-05 lt\n"
+"or{/flipXY 1 def}{/flipXY 0 def}ifelse}ifelse/erosion 1 def systemdict\n"
+"/internaldict known{1183615869 systemdict/internaldict get exec dup/erosion\n"
+"known{/erosion get/erosion exch def}{pop}ifelse}if yflag{flipXY 0 eq c3y2 c4y2\n"
+"eq or{false PickCoords}{/shrink c3y2 c4y2 eq{0}{c1y2 c4y2 sub c3y2 c4y2 sub\n"
+"div abs}ifelse def/yshrink{c4y2 sub shrink mul c4y2 add}def/c1y0 c3y0 yshrink\n"
+"def/c1y1 c3y1 yshrink def/c2y0 c4y0 yshrink def/c2y1 c4y1 yshrink def/c1x0\n"
+"c3x0 def/c1x1 c3x1 def/c2x0 c4x0 def/c2x1 c4x1 def/dY 0 c3y2 c1y2 sub round\n"
+"dtransform flipXY 1 eq{exch}if pop abs def dY dmin lt PickCoords y2 c1y2 sub\n"
+"abs .001 gt{c1x2 c1y2 transform flipXY 1 eq{exch}if/cx exch def/cy exch def/dY\n"
+"0 y2 c1y2 sub round dtransform flipXY 1 eq{exch}if pop def dY round dup 0 ne{\n"
+"/dY exdef}{pop dY 0 lt{-1}{1}ifelse/dY exdef}ifelse/erode PaintType 2 ne\n"
+"erosion .5 ge and def erode{/cy cy .5 sub def}if/ey cy dY add def/ey ey\n"
+"ceiling ey sub ey floor add def erode{/ey ey .5 add def}if ey cx flipXY 1 eq{\n"
+"exch}if itransform exch pop y2 sub/eShift exch def/y1 y1 eShift add def/y2 y2\n"
+"eShift add def/y3 y3 eShift add def}if}ifelse}{flipXY 0 eq c3x2 c4x2 eq or{\n"
+"false PickCoords}{/shrink c3x2 c4x2 eq{0}{c1x2 c4x2 sub c3x2 c4x2 sub div abs}\n"
+"ifelse def/xshrink{c4x2 sub shrink mul c4x2 add}def/c1x0 c3x0 xshrink def/c1x1\n"
+"c3x1 xshrink def/c2x0 c4x0 xshrink def/c2x1 c4x1 xshrink def/c1y0 c3y0 def\n"
+"/c1y1 c3y1 def/c2y0 c4y0 def/c2y1 c4y1 def/dX c3x2 c1x2 sub round 0 dtransform\n"
+"flipXY -1 eq{exch}if pop abs def dX dmin lt PickCoords x2 c1x2 sub abs .001 gt\n"
+"{c1x2 c1y2 transform flipXY -1 eq{exch}if/cy exch def/cx exch def/dX x2 c1x2\n"
+"sub round 0 dtransform flipXY -1 eq{exch}if pop def dX round dup 0 ne{/dX\n"
+"exdef}{pop dX 0 lt{-1}{1}ifelse/dX exdef}ifelse/erode PaintType 2 ne erosion\n"
+".5 ge and def erode{/cx cx .5 sub def}if/ex cx dX add def/ex ex ceiling ex sub\n"
+"ex floor add def erode{/ex ex .5 add def}if ex cy flipXY -1 eq{exch}if\n"
+"itransform pop x2 sub/eShift exch def/x1 x1 eShift add def/x2 x2 eShift add\n"
+"def/x3 x3 eShift add def}if}ifelse}ifelse x2 x5 eq y2 y5 eq or{x5 y5 lineto}{\n"
+"x0 y0 x1 y1 x2 y2 curveto x3 y3 x4 y4 x5 y5 curveto}ifelse epY epX}systemdict\n"
+"/currentpacking known{exch setpacking}if/exec cvx/end cvx]cvx executeonly exch\n"
+"{pop true exch restore}{systemdict/internaldict known not{1183615869 userdict\n"
+"/internaldict get exec exch/FlxProc exch put true}{1183615869 systemdict\n"
+"/internaldict get exec dup length exch maxlength eq{false}{1183615869\n"
+"systemdict/internaldict get exec exch/FlxProc exch put true}ifelse}ifelse}\n"
+"ifelse{systemdict/internaldict known{{1183615869 systemdict/internaldict get\n"
+"exec/FlxProc get exec}}{{1183615869 userdict/internaldict get exec/FlxProc get\n"
+"exec}}ifelse executeonly}if{gsave currentpoint newpath moveto}executeonly{\n"
+"currentpoint grestore gsave currentpoint newpath moveto}executeonly{systemdict\n"
+"/internaldict known not{pop 3}{1183615869 systemdict/internaldict get exec dup\n"
+"/startlock known{/startlock get exec}{dup/strtlck known{/strtlck get exec}{pop\n"
+"3}ifelse}ifelse}ifelse}executeonly]def";
+
+#else
+
+static const char* othersubrs_code = "/OtherSubrs\n"
 "[\n"
-"systemdict /internaldict known not\n"
-"{ 100 dict /begin cvx /mtx matrix /def cvx } if\n"
-"systemdict /currentpacking known {currentpacking true setpacking} if\n"
-"{\n"
-"systemdict /internaldict known {\n"
-"1183615869 systemdict /internaldict get exec\n"
-"dup /$FlxDict known not {\n"
-"dup dup length exch maxlength eq\n"
-"{ pop userdict dup /$FlxDict known not\n"
-"{ 100 dict begin /mtx matrix def\n"
-"\n"
-"dup /$FlxDict currentdict put end } if }\n"
-"{ 100 dict begin /mtx matrix def\n"
-"dup /$FlxDict currentdict put end }\n"
-"ifelse\n"
-"} if\n"
-"/$FlxDict get begin\n"
-"} if\n"
-"grestore\n"
-"/exdef {exch def} def\n"
-"/dmin exch abs 100 div def\n"
-"/epX exdef /epY exdef\n"
-"/c4y2 exdef /c4x2 exdef /c4y1 exdef /c4x1 exdef /c4y0 exdef /c4x0 exdef\n"
-"/c3y2 exdef /c3x2 exdef /c3y1 exdef /c3x1 exdef /c3y0 exdef /c3x0 exdef\n"
-"/c1y2 exdef /c1x2 exdef /c2x2 c4x2 def /c2y2 c4y2 def\n"
-"/yflag c1y2 c3y2 sub abs c1x2 c3x2 sub abs gt def\n"
-"/PickCoords {\n"
-"{c1x0 c1y0 c1x1 c1y1 c1x2 c1y2 c2x0 c2y0 c2x1 c2y1 c2x2 c2y2 }\n"
-"{c3x0 c3y0 c3x1 c3y1 c3x2 c3y2 c4x0 c4y0 c4x1 c4y1 c4x2 c4y2 }\n"
-"ifelse\n"
-"/y5 exdef /x5 exdef /y4 exdef /x4 exdef /y3 exdef /x3 exdef\n"
-"/y2 exdef /x2 exdef /y1 exdef /x1 exdef /y0 exdef /x0 exdef\n"
-"} def\n"
-"mtx currentmatrix pop\n"
-"mtx 0 get abs .00001 lt mtx 3 get abs .00001 lt or\n"
-"{/flipXY -1 def }\n"
-"{mtx 1 get abs .00001 lt mtx 2 get abs .00001 lt or\n"
-"{/flipXY 1 def }\n"
-"{/flipXY 0 def }\n"
-"ifelse }\n"
-"ifelse\n"
-"/erosion 1 def\n"
-"systemdict /internaldict known {\n"
-"1183615869 systemdict /internaldict get exec dup\n"
-"/erosion known\n"
-"{/erosion get /erosion exch def}\n"
-"{pop}\n"
-"ifelse\n"
-"} if\n"
-"yflag\n"
-"{flipXY 0 eq c3y2 c4y2 eq or\n"
-"{false PickCoords }\n"
-"{/shrink c3y2 c4y2 eq\n"
-"{0}{c1y2 c4y2 sub c3y2 c4y2 sub div abs} ifelse def\n"
-"/yshrink {c4y2 sub shrink mul c4y2 add} def\n"
-"/c1y0 c3y0 yshrink def /c1y1 c3y1 yshrink def\n"
-"/c2y0 c4y0 yshrink def /c2y1 c4y1 yshrink def\n"
-"/c1x0 c3x0 def /c1x1 c3x1 def /c2x0 c4x0 def /c2x1 c4x1 def\n"
-"/dY 0 c3y2 c1y2 sub round\n"
-"dtransform flipXY 1 eq {exch} if pop abs def\n"
-"dY dmin lt PickCoords\n"
-"y2 c1y2 sub abs 0.001 gt {\n"
-"c1x2 c1y2 transform flipXY 1 eq {exch} if\n"
-"/cx exch def /cy exch def\n"
-"/dY 0 y2 c1y2 sub round dtransform flipXY 1 eq {exch}\n"
-"if pop def\n"
-"dY round dup 0 ne\n"
-"{/dY exdef }\n"
-"{pop dY 0 lt {-1}{1} ifelse /dY exdef }\n"
-"ifelse\n"
-"/erode PaintType 2 ne erosion 0.5 ge and def\n"
-"erode {/cy cy 0.5 sub def} if\n"
-"/ey cy dY add def\n"
-"/ey ey ceiling ey sub ey floor add def\n"
-"erode {/ey ey 0.5 add def} if\n"
-"ey cx flipXY 1 eq {exch} if itransform exch pop\n"
-"y2 sub /eShift exch def\n"
-"/y1 y1 eShift add def /y2 y2 eShift add def /y3 y3\n"
-"eShift add def\n"
-"} if\n"
-"} ifelse\n"
-"}\n"
-"{flipXY 0 eq c3x2 c4x2 eq or\n"
-"{false PickCoords }\n"
-"{/shrink c3x2 c4x2 eq\n"
-"{0}{c1x2 c4x2 sub c3x2 c4x2 sub div abs} ifelse def\n"
-"/xshrink {c4x2 sub shrink mul c4x2 add} def\n"
-"/c1x0 c3x0 xshrink def /c1x1 c3x1 xshrink def\n"
-"/c2x0 c4x0 xshrink def /c2x1 c4x1 xshrink def\n"
-"/c1y0 c3y0 def /c1y1 c3y1 def /c2y0 c4y0 def /c2y1 c4y1 def\n"
-"/dX c3x2 c1x2 sub round 0 dtransform\n"
-"flipXY -1 eq {exch} if pop abs def\n"
-"dX dmin lt PickCoords\n"
-"x2 c1x2 sub abs 0.001 gt {\n"
-"c1x2 c1y2 transform flipXY -1 eq {exch} if\n"
-"/cy exch def /cx exch def\n"
-"/dX x2 c1x2 sub round 0 dtransform flipXY -1 eq {exch} if pop def\n"
-"dX round dup 0 ne\n"
-"{/dX exdef }\n"
-"{pop dX 0 lt {-1}{1} ifelse /dX exdef }\n"
-"ifelse\n"
-"/erode PaintType 2 ne erosion .5 ge and def\n"
-"erode {/cx cx .5 sub def} if\n"
-"/ex cx dX add def\n"
-"/ex ex ceiling ex sub ex floor add def\n"
-"erode {/ex ex .5 add def} if\n"
-"ex cy flipXY -1 eq {exch} if itransform pop\n"
-"x2 sub /eShift exch def\n"
-"/x1 x1 eShift add def /x2 x2 eShift add def /x3 x3 eShift add def\n"
-"} if\n"
-"} ifelse\n"
-"} ifelse\n"
-"x2 x5 eq y2 y5 eq or\n"
-"{ x5 y5 lineto }\n"
-"{ x0 y0 x1 y1 x2 y2 curveto\n"
-"x3 y3 x4 y4 x5 y5 curveto }\n"
-"ifelse\n"
-"epY epX\n"
-"}\n"
-"systemdict /currentpacking known {exch setpacking} if\n"
-"/exec cvx /end cvx ] cvx\n"
-"executeonly\n"
-"exch\n"
-"{pop true exch restore}\n"
-"{\n"
-"systemdict /internaldict known not\n"
-"{1183615869 userdict /internaldict get exec\n"
-"exch /FlxProc exch put true}\n"
-"{1183615869 systemdict /internaldict get exec\n"
-"dup length exch maxlength eq\n"
-"{false}\n"
-"{1183615869 systemdict /internaldict get exec\n"
-"exch /FlxProc exch put true}\n"
-"ifelse}\n"
-"ifelse}\n"
-"ifelse\n"
-"{systemdict /internaldict known\n"
-"{{1183615869 systemdict /internaldict get exec /FlxProc get exec}}\n"
-"{{1183615869 userdict /internaldict get exec /FlxProc get exec}}\n"
-"ifelse executeonly\n"
-"} if\n"
+"{pop pop pop grestore 12 6 roll curveto curveto pop pop} executeonly\n"
 "{gsave currentpoint newpath moveto} executeonly\n"
-"{currentpoint grestore gsave currentpoint newpath moveto}\n"
-"executeonly\n"
-"{systemdict /internaldict known not\n"
-"{pop 3}\n"
-"{1183615869 systemdict /internaldict get exec\n"
-"dup /startlock known\n"
-"{/startlock get exec}\n"
-"{dup /strtlck known\n"
-"{/strtlck get exec}\n"
-"{pop 3}\n"
-"ifelse}\n"
-"ifelse}\n"
-"ifelse\n"
-"} executeonly\n"
+"{currentpoint currentpoint newpath moveto} executeonly\n"
+"{} executeonly\n"
 "] noaccess def";
 
+#endif
+
 
 Type1Font *
 Type1Font::skeleton_make(PermString font_name, const String &version)
